@@ -19,7 +19,8 @@
  ***************************************************************************/
 
 #include "DummyTest.h"
-#include <modeltest.h>
+#include <tests/modeltest.h>
+#include <KFormat>
 #include <resources/ResourcesModel.h>
 #include <resources/ResourcesProxyModel.h>
 #include <resources/AbstractBackendUpdater.h>
@@ -52,8 +53,6 @@ public:
     UpdateDummyTest(QObject* parent = nullptr): QObject(parent)
     {
         m_model = new ResourcesModel(QStringLiteral("dummy-backend"), this);
-//         new ModelTest(m_model, m_model);
-
         m_appBackend = backendByName(m_model, QStringLiteral("DummyBackend"));
     }
 
@@ -70,47 +69,37 @@ private Q_SLOTS:
     void testUpdate()
     {
         ResourcesUpdatesModel* rum = new ResourcesUpdatesModel(this);
-//         new ModelTest(rum, rum);
+        new ModelTest(rum, rum);
 
         UpdateModel* m = new UpdateModel(this);
-//         new ModelTest(m, m);
+        new ModelTest(m, m);
         m->setBackend(rum);
 
         rum->prepare();
-        QCOMPARE(m_appBackend->updatesCount(), 212);
+        QSignalSpy spySetup(m_appBackend->backendUpdater(), &AbstractBackendUpdater::progressingChanged);
+        QVERIFY(!m_appBackend->backendUpdater()->isProgressing() || spySetup.wait());
+        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt()*2/3);
         QCOMPARE(m->hasUpdates(), true);
 
         for(int i=0, c=m->rowCount(); i<c; ++i) {
-            const QModelIndex idx = m->index(i,0);
+            const QModelIndex resourceIdx = m->index(i,0);
+            QVERIFY(resourceIdx.isValid());
 
-            QVERIFY(!idx.data(UpdateModel::ResourceRole).value<QObject*>());
-            QCOMPARE(idx.data(UpdateModel::SizeRole).toString(), QStringLiteral("12.7 KiB"));
-            for(int j=0, c=m->rowCount(idx); j<c; ++j) {
-                const QModelIndex resourceIdx = idx.child(j,0);
-                QVERIFY(resourceIdx.isValid());
+            AbstractResource* res = qobject_cast<AbstractResource*>(resourceIdx.data(UpdateModel::ResourceRole).value<QObject*>());
+            QVERIFY(res);
 
-                AbstractResource* res = qobject_cast<AbstractResource*>(resourceIdx.data(UpdateModel::ResourceRole).value<QObject*>());
-                QVERIFY(res);
-                QCOMPARE(resourceIdx.data(UpdateModel::SizeRole).toString(), QStringLiteral("123 B"));
+            QCOMPARE(Qt::CheckState(resourceIdx.data(Qt::CheckStateRole).toInt()), Qt::Checked);
+            QVERIFY(m->setData(resourceIdx, int(Qt::Unchecked), Qt::CheckStateRole));
+            QCOMPARE(Qt::CheckState(resourceIdx.data(Qt::CheckStateRole).toInt()), Qt::Unchecked);
+            QCOMPARE(resourceIdx.data(Qt::DisplayRole).toString(), res->name());
 
-                QCOMPARE(Qt::CheckState(resourceIdx.data(Qt::CheckStateRole).toInt()), Qt::Checked);
-                QVERIFY(m->setData(resourceIdx, int(Qt::Unchecked), Qt::CheckStateRole));
-                QCOMPARE(Qt::CheckState(resourceIdx.data(Qt::CheckStateRole).toInt()), Qt::Unchecked);
-                QCOMPARE(resourceIdx.data(Qt::DisplayRole).toString(), res->name());
-
-                if (j!=0) {
-                    QVERIFY(m->setData(resourceIdx, int(Qt::Checked), Qt::CheckStateRole));
-                }
+            if (i!=0) {
+                QVERIFY(m->setData(resourceIdx, int(Qt::Checked), Qt::CheckStateRole));
             }
         }
 
-
-        rum->updateAll();
-
         QSignalSpy spy(rum, &ResourcesUpdatesModel::progressingChanged);
-        QVERIFY(spy.wait());
-        QCOMPARE(rum->isProgressing(), true);
-        QVERIFY(spy.wait());
+        QVERIFY(!rum->isProgressing() || spy.wait());
         QCOMPARE(rum->isProgressing(), false);
 
         QCOMPARE(m_appBackend->updatesCount(), m->rowCount());
