@@ -22,7 +22,7 @@
 #define KNSRESOURCE_H
 
 #include <resources/AbstractResource.h>
-#include <kns3/entry.h>
+#include <KNSCore/EntryInternal>
 #include <attica/content.h>
 
 #include "discovercommon_export.h"
@@ -32,7 +32,7 @@ class DISCOVERCOMMON_EXPORT KNSResource : public AbstractResource
 {
 Q_OBJECT
 public:
-    explicit KNSResource(const KNS3::Entry& c, QString category, KNSBackend* parent);
+    explicit KNSResource(const KNSCore::EntryInternal & c, QStringList categories, KNSBackend* parent);
     ~KNSResource() override;
 
     AbstractResource::State state() override;
@@ -56,12 +56,14 @@ public:
     void fetchChangelog() override;
     QStringList extends() const override;
 
-    void setEntry(const KNS3::Entry& entry);
-    KNS3::Entry entry() const;
+    KNSBackend* knsBackend() const;
+
+    void setEntry(const KNSCore::EntryInternal& entry);
+    KNSCore::EntryInternal entry() const;
 
 private:
-    const QString m_category;
-    KNS3::Entry m_entry;
+    const QStringList m_categories;
+    KNSCore::EntryInternal m_entry;
 };
 
 #endif // KNSRESOURCE_H
