@@ -19,6 +19,7 @@
  ***************************************************************************/
 
 #include "KNSBackendTest.h"
+#include "utils.h"
 #include <KNSBackend.h>
 #include <KXmlGuiWindow>
 #include <resources/AbstractBackendUpdater.h>
@@ -27,6 +28,8 @@
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <ReviewsBackend/Review.h>
 #include <ReviewsBackend/Rating.h>
+#include <Category/Category.h>
+#include <Category/CategoryModel.h>
 #include <DiscoverBackendsFactory.h>
 #include <QStandardPaths>
 
@@ -40,42 +43,52 @@ KNSBackendTest::KNSBackendTest(QObject* parent)
     , m_r(nullptr)
 {
     QStandardPaths::setTestModeEnabled(true);
-    ResourcesModel* model = new ResourcesModel(QFINDTESTDATA("knscorrect-backend.desktop"), this);
+    ResourcesModel* model = new ResourcesModel(QLatin1String("kns-backend"), this);
     Q_ASSERT(!model->backends().isEmpty());
-    m_backend = model->backends().at(0);
+    auto findTestBackend = [](AbstractResourcesBackend* backend) {
+        return backend->name() == QLatin1String("discover_ktexteditor_codesnippets_core.knsrc");
+    };
+    m_backend = kFilter<QVector<AbstractResourcesBackend*>>(model->backends(), findTestBackend).at(0);
 
     if (!m_backend->isValid()) {
         qWarning() << "couldn't run the test";
         exit(0);
     }
 
-    QSignalSpy s(model, SIGNAL(allInitialized()));
-    Q_ASSERT(s.wait(50000));
     connect(m_backend->reviewsBackend(), &AbstractReviewsBackend::reviewsReady, this, &KNSBackendTest::reviewsArrived);
 }
 
-void KNSBackendTest::wrongBackend()
+QVector<AbstractResource*> KNSBackendTest::getResources(ResultsStream* stream)
 {
-    DiscoverBackendsFactory f;
-    AbstractResourcesBackend* b = f.backendForFile(QFINDTESTDATA("knswrong-backend.desktop"), QStringLiteral("knswrong-backend"));
-    QVERIFY(!b->isValid());
+    Q_ASSERT(stream);
+    Q_ASSERT(stream->objectName() != QLatin1String("KNS-void"));
+    QSignalSpy spyResources(stream, &ResultsStream::destroyed);
+    QVector<AbstractResource*> resources;
+    connect(stream, &ResultsStream::resourcesFound, this, [&resources](const QVector<AbstractResource*>& res) { resources += res; });
+    Q_ASSERT(spyResources.wait());
+    Q_ASSERT(!resources.isEmpty());
+    return resources;
+}
+
+QVector<AbstractResource*> KNSBackendTest::getAllResources(AbstractResourcesBackend* backend)
+{
+    AbstractResourcesBackend::Filters f;
+    f.category = CategoryModel::global()->rootCategories().first();
+    return getResources(backend->search(f));
 }
 
 void KNSBackendTest::testRetrieval()
 {
-    ResourcesModel* model = ResourcesModel::global();
-    QVector<AbstractResource*> resources = m_backend->allResources();
-    QVERIFY(!resources.isEmpty());
-    QCOMPARE(resources.count(), model->rowCount());
     QVERIFY(m_backend->backendUpdater());
     QCOMPARE(m_backend->updatesCount(), m_backend->backendUpdater()->toUpdate().count());
-    
+
+    const auto resources = getAllResources(m_backend);
     foreach(AbstractResource* res, resources) {
         QVERIFY(!res->name().isEmpty());
         QVERIFY(!res->categories().isEmpty());
         QVERIFY(!res->origin().isEmpty());
         QVERIFY(!res->icon().isNull());
-        QVERIFY(!res->comment().isEmpty());
+//         QVERIFY(!res->comment().isEmpty());
 //         QVERIFY(!res->longDescription().isEmpty());
 //         QVERIFY(!res->license().isEmpty());
         QVERIFY(res->homepage().isValid() && !res->homepage().isEmpty());
@@ -96,7 +109,7 @@ void KNSBackendTest::testRetrieval()
 
 void KNSBackendTest::testReviews()
 {
-    QVector<AbstractResource*> resources = m_backend->allResources();
+    const QVector<AbstractResource*> resources = getAllResources(m_backend);
     AbstractReviewsBackend* rev = m_backend->reviewsBackend();
     QVERIFY(!rev->hasCredentials());
     foreach(AbstractResource* res, resources) {
@@ -117,3 +130,10 @@ void KNSBackendTest::reviewsArrived(AbstractResource* r, const QList< Review* >&
     m_r = r;
     m_revs = revs;
 }
+
+void KNSBackendTest::testResourceByUrl()
+{
+    const auto res = getResources(ResourcesModel::global()->findResourceByPackageName(QUrl(QStringLiteral("kns://plasma-themes.knsrc/api.kde-look.org/1136471"))));
+    QCOMPARE(res.count(), 1);
+}
+
