@@ -22,10 +22,12 @@
 #include "PackageKitBackend.h"
 #include "PackageKitResource.h"
 #include "PackageKitMessages.h"
+#include "utils.h"
+#include "LocalFilePKResource.h"
 #include <resources/AbstractResource.h>
 #include <Transaction/TransactionModel.h>
 #include <QDebug>
-#include <QMessageBox>
+#include <QTimer>
 #include <KLocalizedString>
 #include <PackageKit/Transaction>
 #include <PackageKit/Daemon>
@@ -40,6 +42,9 @@ PKTransaction::PKTransaction(const QVector<AbstractResource*>& apps, Transaction
         PackageKitResource* res = qobject_cast<PackageKitResource*>(r);
         m_pkgnames.unite(res->allPackageNames().toSet());
     }
+
+    TransactionModel::global()->addTransaction(this);
+    QTimer::singleShot(0, this, &PKTransaction::start);
 }
 
 static QStringList packageIds(const QVector<AbstractResource*>& res, std::function<QString(PackageKitResource*)> func)
@@ -63,7 +68,9 @@ void PKTransaction::trigger(PackageKit::Transaction::TransactionFlags flags)
         m_trans->deleteLater();
     m_newPackageStates.clear();
 
-    switch (role()) {
+    if (m_apps.size() == 1 && qobject_cast<LocalFilePKResource*>(m_apps.at(0))) {
+        m_trans = PackageKit::Daemon::installFile(QUrl(m_apps.at(0)->packageName()).toLocalFile(), flags);
+    } else switch (role()) {
         case Transaction::ChangeAddonsRole:
         case Transaction::InstallRole:
             m_trans = PackageKit::Daemon::installPackages(packageIds(m_apps, [](PackageKitResource* r){return r->availablePackageId(); }), flags);
@@ -109,8 +116,7 @@ void PKTransaction::cancellableChanged()
 void PKTransaction::cancel()
 {
     if (!m_trans) {
-        const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
-        backend->transactionCanceled(this);
+        TransactionModel::global()->cancelTransaction(this);
     } else if (m_trans->allowCancel()) {
         m_trans->cancel();
     } else {
@@ -135,7 +141,7 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
         QSet<AbstractResource*> removedResources;
         while (i.hasNext()) {
             const auto pkgname = PackageKit::Daemon::packageName(i.next());
-            removedResources.unite(backend->searchPackageName(pkgname).toSet());
+            removedResources.unite(backend->resourcesByPackageName(pkgname));
 
             if (m_pkgnames.contains(pkgname)) {
                 i.remove();
@@ -145,16 +151,13 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
 
         QString msg = PackageKitResource::joinPackages(packagesToRemove);
         if (!removedResources.isEmpty()) {
-            QStringList removedResourcesStr;
-            removedResourcesStr.reserve(removedResources.size());
-            foreach(AbstractResource* res, removedResources)
-                removedResourcesStr.append(res->name());
+            const QStringList removedResourcesStr = kTransform<QStringList>(removedResources, [](AbstractResource* a) { return a->name(); });
             msg += QLatin1Char('\n');
             msg += removedResourcesStr.join(QStringLiteral(", "));
         }
 
         if (!msg.isEmpty()) {
-            Q_EMIT proceedRequest(PackageKitMessages::statusMessage(PackageKit::Transaction::StatusRemove), msg);
+            Q_EMIT proceedRequest(i18n("Confirm..."), i18np("To proceed with this action, the following package needs removal:\n%2", "To proceed with this action, the following packages need removal:\n%2", packagesToRemove.count(), msg));
         } else {
             proceed();
         }
@@ -164,13 +167,18 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
     this->submitResolve();
     setStatus(Transaction::DoneStatus);
     if (cancel)
-        backend->transactionCanceled(this);
+        TransactionModel::global()->cancelTransaction(this);
     else
-        backend->removeTransaction(this);
+        TransactionModel::global()->removeTransaction(this);
 }
 
 void PKTransaction::proceed()
 {
+    if (!m_requiredEula.isEmpty()) {
+        PackageKit::Transaction* t = PackageKit::Daemon::acceptEula(m_requiredEula.takeFirst());
+        connect(t, &PackageKit::Transaction::finished, this, &PKTransaction::start);
+        return;
+    }
     trigger(PackageKit::Transaction::TransactionFlagOnlyTrusted);
 }
 
@@ -188,8 +196,10 @@ void PKTransaction::submitResolve()
     }
     const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
 
-    backend->clearPackages(needResolving);
-    backend->resolvePackages(needResolving);
+    if (!needResolving.isEmpty()) {
+        backend->clearPackages(needResolving);
+        backend->resolvePackages(needResolving);
+    }
 }
 
 PackageKit::Transaction* PKTransaction::transaction()
@@ -199,14 +209,9 @@ PackageKit::Transaction* PKTransaction::transaction()
 
 void PKTransaction::eulaRequired(const QString& eulaID, const QString& packageID, const QString& vendor, const QString& licenseAgreement)
 {
-    int ret = QMessageBox::question(nullptr, i18n("Accept EULA"), i18n("The package %1 and its vendor %2 require that you accept their license:\n %3",
+    m_requiredEula += eulaID;
+    Q_EMIT proceedRequest(i18n("Accept EULA"), i18n("The package %1 and its vendor %2 require that you accept their license:\n %3",
                                                  PackageKit::Daemon::packageName(packageID), vendor, licenseAgreement));
-    if (ret == QMessageBox::Yes) {
-        PackageKit::Transaction* t = PackageKit::Daemon::acceptEula(eulaID);
-        connect(t, &PackageKit::Transaction::finished, this, &PKTransaction::start);
-    } else {
-        cleanup(PackageKit::Transaction::ExitCancelled, 0);
-    }
 }
 
 void PKTransaction::errorFound(PackageKit::Transaction::Error err, const QString& error)
